import type { CreatePermission } from '../models/CreatePermission';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { ResponsePermission } from '../models/ResponsePermission';
import type { ResponsePrincipal } from '../models/ResponsePrincipal';
import type { UpdatePermission } from '../models/UpdatePermission';
export declare class PermissionService {
    /**
     * Get all
     * Lists all permissions for all users and groups.
     * @result ResponsePermission
     * @throws ApiError
     */
    static permissionControllerGetAll(): Promise<Array<ResponsePermission>>;
    /**
     * Post
     * Create a new permission for a existing principal(user/group). <br> If a permission with this target, action and prinicpal already exists that permission will be returned instead of creating a new one.
     * @param requestBody CreatePermission
     * @result ResponsePermission
     * @throws ApiError
     */
    static permissionControllerPost(requestBody?: CreatePermission): Promise<ResponsePermission>;
    /**
     * Get one
     * Lists all information about the permission whose id got provided.
     * @param id
     * @result ResponsePermission
     * @throws ApiError
     */
    static permissionControllerGetOne(id: number): Promise<ResponsePermission>;
    /**
     * Put
     * Update a permission object. <br> If updateing the permission object would result in duplicate permission (same target, action and principal) this permission will get deleted and the existing permission will be returned. <br> Please remember that ids can't be changed.
     * @param id
     * @param requestBody UpdatePermission
     * @result ResponsePrincipal
     * @throws ApiError
     */
    static permissionControllerPut(id: number, requestBody?: UpdatePermission): Promise<ResponsePrincipal>;
    /**
     * Remove
     * Deletes the permission whose id you provide. <br> If no permission with this id exists it will just return 204(no content).
     * @param id
     * @param force
     * @result ResponsePermission
     * @result ResponseEmpty
     * @throws ApiError
     */
    static permissionControllerRemove(id: number, force?: boolean): Promise<ResponsePermission | ResponseEmpty>;
}
