import type { CreateRunnerCard } from '../models/CreateRunnerCard';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { ResponseRunnerCard } from '../models/ResponseRunnerCard';
import type { UpdateRunnerCard } from '../models/UpdateRunnerCard';
export declare class RunnerCardService {
    /**
     * Get all
     * Lists all card.
     * @result ResponseRunnerCard
     * @throws ApiError
     */
    static runnerCardControllerGetAll(): Promise<Array<ResponseRunnerCard>>;
    /**
     * Post
     * Create a new card. <br> You can provide a associated runner by id but you don't have to.
     * @param requestBody CreateRunnerCard
     * @result ResponseRunnerCard
     * @throws ApiError
     */
    static runnerCardControllerPost(requestBody?: CreateRunnerCard): Promise<ResponseRunnerCard>;
    /**
     * Get one
     * Lists all information about the card whose id got provided.
     * @param id
     * @result ResponseRunnerCard
     * @throws ApiError
     */
    static runnerCardControllerGetOne(id: number): Promise<ResponseRunnerCard>;
    /**
     * Put
     * Update the card whose id you provided. <br> Scans created via this card will still be associated with the old runner. <br> Please remember that ids can't be changed.
     * @param id
     * @param requestBody UpdateRunnerCard
     * @result ResponseRunnerCard
     * @throws ApiError
     */
    static runnerCardControllerPut(id: number, requestBody?: UpdateRunnerCard): Promise<ResponseRunnerCard>;
    /**
     * Remove
     * Delete the card whose id you provided. <br> If no card with this id exists it will just return 204(no content). <br> If the card still has scans associated you have to provide the force=true query param (warning: this deletes all scans associated with by this card - please disable it instead or just remove the runner association).
     * @param id
     * @param force
     * @result ResponseRunnerCard
     * @result ResponseEmpty
     * @throws ApiError
     */
    static runnerCardControllerRemove(id: number, force?: boolean): Promise<ResponseRunnerCard | ResponseEmpty>;
    /**
     * Post blanco bulk
     * Create blank cards in bulk. <br> Just provide the count as a query param and wait for the 200 response. <br> You can provide the 'returnCards' query param if you want to receive the RESPONSERUNNERCARD objects in the response.
     * @param count
     * @param returnCards
     * @result ResponseEmpty
     * @throws ApiError
     */
    static runnerCardControllerPostBlancoBulk(count?: number, returnCards?: boolean): Promise<ResponseEmpty>;
}
