import type { CreateRunnerTeam } from '../models/CreateRunnerTeam';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { ResponseRunner } from '../models/ResponseRunner';
import type { ResponseRunnerTeam } from '../models/ResponseRunnerTeam';
import type { UpdateRunnerTeam } from '../models/UpdateRunnerTeam';
export declare class RunnerTeamService {
    /**
     * Get all
     * Lists all teams. <br> This includes their parent organization and contact (if existing/associated).
     * @result ResponseRunnerTeam
     * @throws ApiError
     */
    static runnerTeamControllerGetAll(): Promise<Array<ResponseRunnerTeam>>;
    /**
     * Post
     * Create a new organsisation. <br> Please remember to provide it's parent group's id.
     * @param requestBody CreateRunnerTeam
     * @result ResponseRunnerTeam
     * @throws ApiError
     */
    static runnerTeamControllerPost(requestBody?: CreateRunnerTeam): Promise<ResponseRunnerTeam>;
    /**
     * Get one
     * Lists all information about the team whose id got provided.
     * @param id
     * @result ResponseRunnerTeam
     * @throws ApiError
     */
    static runnerTeamControllerGetOne(id: number): Promise<ResponseRunnerTeam>;
    /**
     * Put
     * Update the team whose id you provided. <br> Please remember that ids can't be changed.
     * @param id
     * @param requestBody UpdateRunnerTeam
     * @result ResponseRunnerTeam
     * @throws ApiError
     */
    static runnerTeamControllerPut(id: number, requestBody?: UpdateRunnerTeam): Promise<ResponseRunnerTeam>;
    /**
     * Remove
     * Delete the team whose id you provided. <br> If the team still has runners associated this will fail. <br> To delete the team with all associated runners set the force QueryParam to true (cascading deletion might take a while). <br> This won't delete the associated contact.<br> If no team with this id exists it will just return 204(no content).
     * @param id
     * @param force
     * @result ResponseRunnerTeam
     * @result ResponseEmpty
     * @throws ApiError
     */
    static runnerTeamControllerRemove(id: number, force?: boolean): Promise<ResponseRunnerTeam | ResponseEmpty>;
    /**
     * Get runners
     * Lists all runners from this team. <br> This includes the runner's group and distance ran.
     * @param id
     * @result ResponseRunner
     * @throws ApiError
     */
    static runnerTeamControllerGetRunners(id: number): Promise<Array<ResponseRunner>>;
}
